The OANDA v20 REST API provides programmatic access to OANDA's next generation
v20 trading engine.

Installation
############

Install using pip::

	pip install v20

If you don't wish to use pip::

	git clone https://github.com/oanda/v20-python.git

Documentation
#############

For documentation, usage and examples, see: http://developer.oanda.com/rest-live-v20/introduction
